package HeliosX::Logger::LoggingError;

use base qw(Error::Simple);

our $VERSION = '0.01_45_7';

1;
__END__;

=head1 NAME

HeliosX::Error::LoggingError - exception class for Helios job processing system to denote a 
logging subsystem error occurred

=head1 SYNOPSIS

 use HeliosX::Error::LoggingError;

 =head1 DESCRIPTION

#[]

=head1 SEE ALSO

L<HeliosX::ExtLoggerService>

=head1 AUTHOR

Andrew Johnson, E<lt>lajandy@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2008 Andrew Johnson.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.0 or,
at your option, any later version of Perl 5 you may have available.

=head1 WARRANTY

This software comes with no warranty of any kind.

=cut

